pub fn from_env() -> ConfigLoader👎Deprecated:
Use the aws_config::defaults function. If you don’t care about future default behavior changes, you can continue to use this function by enabling the behavior-version-latest feature. Doing so will make this deprecation notice go away.
Create a config loader with the latest defaults.