pub async fn load_from_env() -> SdkConfig👎Deprecated:
Use the aws_config::load_defaults function. If you don’t care about future default behavior changes, you can continue to use this function by enabling the behavior-version-latest feature. Doing so will make this deprecation notice go away.
Load default configuration with the latest defaults.